// main.cpp
#include "../lib/myDynamicLibrary/myDynamicLibrary.h"
#include <iostream>
#include <SDL2/SDL.h>
#include <SDL2/SDL_ttf.h>
using namespace std;

myDynamicLibrary myObj;

const int WINDOW_WIDTH = 800;
const int WINDOW_HEIGHT = 600;

int main(int argc, char* argv[]) {
    // SDL en TTF initialiseren
    if (SDL_Init(SDL_INIT_VIDEO) < 0) {
        cerr << "SDL kon niet initialiseren: " << SDL_GetError() << endl;
        return 1;
    }
    if (TTF_Init() == -1) {
        cerr << "TTF kon niet initialiseren: " << TTF_GetError() << endl;
        SDL_Quit();
        return 1;
    }

    // SDL Window en Renderer aanmaken
    SDL_Window* window = SDL_CreateWindow("SDL2 Demo", SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, WINDOW_WIDTH, WINDOW_HEIGHT, SDL_WINDOW_SHOWN);
    if (!window) {
        cerr << "Kan window niet maken: " << SDL_GetError() << endl;
        TTF_Quit();
        SDL_Quit();
        return 1;
    }

    SDL_Renderer* renderer = SDL_CreateRenderer(window, -1, SDL_RENDERER_ACCELERATED);
    if (!renderer) {
        cerr << "Kan renderer niet maken: " << SDL_GetError() << endl;
        SDL_DestroyWindow(window);
        TTF_Quit();
        SDL_Quit();
        return 1;
    }

    // Laad een font
    TTF_Font* font = TTF_OpenFont("../include/Open_Sans/static/OpenSans-Regular.ttf", 24);
    if (!font) {
        cerr << "Kan font niet laden: " << TTF_GetError() << endl;
        SDL_DestroyRenderer(renderer);
        SDL_DestroyWindow(window);
        TTF_Quit();
        SDL_Quit();
        return 1;
    }

    SDL_Color textColor = {255, 255, 255, 255};

    myObj.a = 50;
    myObj.b = 10;
    std::string text_string = myObj.sayHelloDynamic();

    const char* text = &text_string[0];

    SDL_Surface* textSurface = TTF_RenderText_Solid(font, text, textColor);
    if (!textSurface) {
        cerr << "Kan text surface niet maken: " << endl;
        return 1;
    }
    SDL_Texture* textTexture = SDL_CreateTextureFromSurface(renderer, textSurface);
    if (!textTexture) {
        cerr << "Kan texture niet maken: " << endl;
        return 1;
    }

    SDL_Rect textRect = {WINDOW_WIDTH / 2 - textSurface->w / 2, WINDOW_HEIGHT / 2 - textSurface->h / 2, textSurface->w, textSurface->h};

    bool running = true;
    SDL_Event event;
    while (running) {
        while (SDL_PollEvent(&event)) {
            if (event.type == SDL_QUIT) {
                running = false;
            }
        }

        SDL_SetRenderDrawColor(renderer, 0, 0, 0, 255);
        SDL_RenderClear(renderer);

        SDL_RenderCopy(renderer, textTexture, nullptr, &textRect);
        SDL_RenderPresent(renderer);
    }

    SDL_DestroyTexture(textTexture);
    TTF_CloseFont(font);
    SDL_DestroyRenderer(renderer);
    SDL_DestroyWindow(window);
    TTF_Quit();
    SDL_Quit();

    return 0;
}